16.139. cdist-type__timezone(7) — cdist 4.10.11 documentation

# 16.139. cdist-type__timezone(7)

## 16.139.1. NAME

cdist-type__timezone - Allows one to configure the desired localtime timezone.

## 16.139.2. DESCRIPTION

This type creates a symlink (/etc/localtime) to the selected timezone (which should be available in /usr/share/zoneinfo).

## 16.139.3. REQUIRED PARAMETERS

None.

## 16.139.4. OPTIONAL PARAMETERS

None.

## 16.139.5. EXAMPLES

    #Set up Europe/Andorra as our timezone.
    __timezone Europe/Andorra

    #Set up US/Central as our timezone.
    __timezone US/Central

## 16.139.6. AUTHORS

Ramon Salvadó <rsalvado--@--gnuine--dot--com>

## 16.139.7. COPYING

Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).